============
Contributing
============

Running tests locally
=====================

.. code-block:: console

    $ python -m pip install --upgrade tox
    $ tox

Fixing formatting errors
------------------------

.. code-block:: console

    $ tox -e format
